ragcode

package
v1.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 13, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AnalyzerManager

type AnalyzerManager struct{}

func NewAnalyzerManager

func NewAnalyzerManager() *AnalyzerManager

func (*AnalyzerManager) CodeAnalyzerForProjectType

func (m *AnalyzerManager) CodeAnalyzerForProjectType(projectType string) codetypes.PathAnalyzer

type Indexer

type Indexer struct {
	// contains filtered or unexported fields
}

Indexer indexes CodeChunks into LongTermMemory using an embedding Provider.

func NewIndexer

func NewIndexer(analyzer codetypes.PathAnalyzer, embedder llm.Provider, ltm memory.LongTermMemory) *Indexer

func (*Indexer) IndexPaths

func (i *Indexer) IndexPaths(ctx context.Context, paths []string, sourceTag string) (int, error)

IndexPaths analyzes, embeds and stores all code chunks under the given paths. collection and dimension management should be handled by the caller (Qdrant client).

type Language

type Language string
const (
	LanguageGo         Language = "go"
	LanguageJava       Language = "java"
	LanguagePHP        Language = "php"
	LanguageHTML       Language = "html"
	LanguagePython     Language = "python"
	LanguageJavascript Language = "javascript"
	LanguageTypescript Language = "typescript"
)

Directories

Path Synopsis
analyzers
php

Jump to